<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>HomeDaemon</name>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="71"/>
        <source>Deepin Home</source>
        <translation>Comunidade</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="83"/>
        <source>Show main window</source>
        <translation>Exibir janela principal</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="89"/>
        <source>Communication</source>
        <translation>Comunicação</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="92"/>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="333"/>
        <source>View</source>
        <translation>Visualizar</translation>
    </message>
</context>
</TS>